@@ -517,7 +517,7 @@ return(out)
 
 ##' @export
 piecewise.twostage <- function(cut1,cut2,data=sys.parent(),timevar="time",status="status",id="id",covars=NULL,num=NULL,
-            score.method="optimize",Nit=60,detail=0,clusters=NULL,silent=1,weights=NULL,
+            score.method="optimize",Nit=100,detail=0,clusters=NULL,silent=1,weights=NULL,
             control=list(),theta=NULL,theta.des=NULL,var.link=1,iid=0,step=0.5,model="plackett",data.return=0)
 { ## {{{
 
@@ -543,7 +543,9 @@ if (silent<=-1) print(summary(datalr));
 datalr$tstime <- datalr[,timevar]
 datalr$tsstatus <- datalr[,status]
 datalr$tsid <- datalr[,id]
-marg1 <- aalen(Surv(boxtime,tsstatus)~-1+factor(num),data=datalr,n.sim=0,max.clust=NULL,robust=0)
+###
+f <- as.formula(with(attributes(datalr),paste("Surv(",time,",",status,")~-1+factor(",num,")")))
+marg1 <- aalen(f,data=datalr,n.sim=0,max.clust=NULL,robust=0)
 fitlr<-  twostage(marg1,data=datalr,clusters=datalr$tsid,model=model,score.method=score.method,
               Nit=Nit,detail=detail,silent=silent,weights=weights,
               control=control,theta=theta,theta.des=theta.des,var.link=var.link,iid=iid,step=step)
